{ config, pkgs, ... }:

{
  environment.systemPackages = with pkgs.haskellPackages; with pkgs; [
    gitg
    gmpc
    m4
    subversion
    openjdk8
    sbt scala
    # firefoxWrapper
    # qutebrowser
    chromium
    # thunderbird
    qalculate-gtk
    speedcrunch
    viewnior
    gnupg
    pass xclip pwgen
    remmina
    ledger
    hledger
    hledger-diff
    cmake
    mpv
    wireshark-gtk
    mutt
    stable.goldendict
    patchelf
    bazaar
    tokei

    pdfpc

    # haskell dev
    cabal2nix
    cabal-install
    ghc-mod

    # emacs
    emacs
    ghostscript # for auctex
    aspell

    mediainfo

    isync
    mu
    msmtp
    vdirsyncer khard khal

    veriT
    minisat
    picosat
    glucose
    prover9
    eprover
    metis-prover
    spass
    z3
    cvc4
    why3
    graphviz
    # toysolver
    stable.haskellPackages.tip-lib

    emacsPackages.proofgeneral_4_3_pre

    stablePkgs # protect nixpkgs checkout from GC
  ] ++ (with aspellDicts; [ en de fr nl ]);

  nixpkgs.config.packageOverrides = pkgs: with pkgs; let
    fetchNixPkgs = { rev, sha256 }:
    fetchFromGitHub {
      inherit sha256 rev;
      owner = "NixOS";
      repo = "nixpkgs-channels";
    };
    stablePkgs = fetchNixPkgs {
      rev = "f231b2b3f79020025eaabe4e8fae53e81651914c";
      sha256 = "0bnac2qsx2j5gl2vfqjswv096fnqvf7d5ids1442mk050yph0gix";
    };
  in {
    idea.idea-community = pkgs.idea.idea-community.overrideDerivation (oldAttrs: rec {
        name = "idea-community-${version}";
        version = "2016.2.eap";
        src = pkgs.fetchurl {
          url = "https://download.jetbrains.com/idea/ideaIC-162.1447.21-no-jdk.tar.gz";
          sha256 = "c8598c33473282acd61d0b19e9629396b90d79ab77909d1363c2c3b58c93783e";
        };
      });

    neovim = pkgs.neovim.override {
      extraPythonPackages = [ pkgs.pythonPackages.websocket_client ];
    };

    stablePkgs = stablePkgs;
    stable = import stablePkgs {};
  };

  nixpkgs.config.allowTexliveBuilds = true;

}
